@@ -6,7 +6,7 @@ import requests
 from requests.exceptions import RequestException
 
 from ..baseclient import BaseClient
-from ..bencode import bencode
+from ..bencode import bdecode, bencode
 from ..exceptions import FailedToExecuteException
 from ..torrent import TorrentData, TorrentFile, TorrentState
 from ..utils import (
@@ -113,11 +113,6 @@ class QBittorrentClient(BaseClient):
         except FailedToExecuteException:
             return False
 
-    def _check_create_subfolder_enabled(self):
-        return self.call("get", "/api/v2/app/preferences").json()[
-            "create_subfolder_enabled"
-        ]
-
     def add(
         self,
         torrent,
@@ -134,40 +129,23 @@ class QBittorrentClient(BaseClient):
             raise FailedToExecuteException(
                 f"Minimum expected data not reached, wanted {minimum_expected_data} actual {current_expected_data}"
             )
-        create_subfolder_enabled = self._check_create_subfolder_enabled()
-        changed_create_subfolder_enabled = False
         encoded_torrent = bencode(torrent)
         data = {
             "savepath": str(destination_path),
             "skip_checking": (fast_resume and "true" or "false"),
             "autoTMM": "false",
+            "root_folder": add_name_to_folder,
+            "contentLayout": (add_name_to_folder and "Original" or "NoSubfolder"),
         }
         if stopped:
             data["paused"] = "true"
 
-        name = torrent[b"info"][b"name"].decode()
-        if b"files" in torrent[b"info"]:
-            if create_subfolder_enabled and not add_name_to_folder:
-                self.call(
-                    "post",
-                    "/api/v2/app/setPreferences",
-                    data={"json": json.dumps({"create_subfolder_enabled": False})},
-                )
-                changed_create_subfolder_enabled = True
-            elif not create_subfolder_enabled and add_name_to_folder:
-                data["savepath"] = destination_path / name
         self.call(
             "post",
             "/api/v2/torrents/add",
             files={"torrents": encoded_torrent},
             data=data,
         )
-        if changed_create_subfolder_enabled:
-            self.call(
-                "post",
-                "/api/v2/app/setPreferences",
-                data={"json": json.dumps({"create_subfolder_enabled": True})},
-            )
 
     def remove(self, infohash):
         self.call(
@@ -180,9 +158,25 @@ class QBittorrentClient(BaseClient):
         if not self.session_path:
             raise FailedToExecuteException("Session path is not configured")
         torrent_path = self.session_path / "data" / "BT_backup" / f"{infohash}.torrent"
+        torrent_resume_path = (
+            self.session_path / "data" / "BT_backup" / f"{infohash}.fastresume"
+        )
+
         if not torrent_path.is_file():
             raise FailedToExecuteException("Torrent file does not exist")
-        return torrent_path.read_bytes()
+        torrent_data = bdecode(torrent_path.read_bytes())
+        if b"announce" not in torrent_data:
+            if not torrent_resume_path.is_file():
+                raise FailedToExecuteException("Torrent resume file does not exist")
+            torrent_resume_data = bdecode(torrent_resume_path.read_bytes())
+            trackers = torrent_resume_data.get(b"trackers")
+            if not trackers:
+                raise FailedToExecuteException("No trackers found in torrent file")
+            torrent_data[b"announce"] = trackers.pop(0)[0]
+            if trackers:
+                torrent_data[b"announce-list"] = trackers
+
+        return bencode(torrent_data)
 
     def get_download_path(self, infohash):
         return self._get_download_path(infohash)[0]
@@ -214,8 +208,6 @@ class QBittorrentClient(BaseClient):
         self.stop(infohash)
         current_download_path, contains_folder_name = self._get_download_path(infohash)
         files = self.get_files(infohash)
-        if contains_folder_name and not self._check_create_subfolder_enabled():
-            destination_path = destination_path / current_download_path.name
 
         move_files(current_download_path, destination_path, files)
         if contains_folder_name:
